@@ -47,7 +47,7 @@ sphinxcontrib.kana_text
 - 「かな|単語^オプション」とする
 - 「^」以降はソート処理では無視される
 
-    - see: IndexRack.sort_units
+    - see: ExIndexRack.sort_units
 
 指定方法
 
@@ -148,10 +148,10 @@ KanaTextクラス
 - かな表示を可能にする.
 - 「.. index::」「..glossary::」「:index:」「:kana:」で使用.
 
-KanaTextUnitクラス
+ExIndexEntryクラス
 
 - 「.. index::」でsingle/pair/tripleと一緒に書かれている用語に対応.
-- IndexUnittクラスに乗る前のKanaTextオブジェクトを保持する.
+- ExIndexUnittクラスに乗る前のKanaTextオブジェクトを保持する.
 
 visit_kana/depart_kanaメソッド
 
@@ -166,20 +166,20 @@ KanaHTML5Translatorクラス/visit_termメソッド
 
     - visit_termメソッドはglossaryで定義された単語（termクラス）が通る.
 
-IndexRackクラス/create_geindex_entriesメソッド
+ExIndexRackクラス/create_geindex_entriesメソッド
 
 - IndexEntriesクラス/create_indexメソッドを置き換える.
 - 可能な限り、内部的な処理順に依存しないようにした.
 - オリジナルは「func() (クラス名やモジュール名)」の集約処理が説明した通りではない.
 - 「see/seealso」の表示順がオリジナルと異なる.
 
-IndexUnitクラス
+ExIndexUnitクラス
 
 - 索引ページで表示される各項目に対応したオブジェクトのクラス.
 
-SubTermクラス
+ExSubTermクラス
 
-- IndexUnitクラス内のsubtermオブジェクトのクラス.
+- ExIndexUnitクラス内のsubtermオブジェクトのクラス.
 - KanaTextを最大で二つ持つ.
 
 KanaHTMLBuilderクラス/create_genindexメソッド
@@ -203,10 +203,10 @@ latexの関連情報
 ==================
 """
 
-__copyright__ = 'Copyright (C) 2021 @koKkekoh/Qiita'
+__copyright__ = 'Copyright (C) 2021 @koKkekoh'
 __license__ = 'BSD 2-Clause License'
 __author__  = '@koKekkoh'
-__version__ = '0.24.1.1' # 2021-10-16
+__version__ = '0.25.0' # 2021-10-24
 __url__     = 'https://qiita.com/tags/sphinxcotrib.kana_text'
 
 import re, pathlib
@@ -226,6 +226,8 @@ from sphinx.util import logging, split_into
 from sphinx.util.nodes import process_index_entry
 from sphinx.writers import html5
 
+import sphindexer as idxr
+
 logger = logging.getLogger(__name__)
 
 #------------------------------------------------------------
@@ -293,9 +295,11 @@ def make_html_with_ruby(word: str, kana: str) -> str:
         >>> make_html_with_ruby("単語","たんご")
         '<ruby><rb>単語</rb><rp>（</rp><rt>たんご</rt><rp>）</rp></ruby>'
     """
+    _word = nodes.unescape(word)
+    _kana = nodes.unescape(kana)
 
-    rb = f'<rb>{word}</rb>' #単語
-    rt = f'<rt>{kana}</rt>' #かな
+    rb = f'<rb>{_word}</rb>' #単語
+    rt = f'<rt>{_kana}</rt>' #かな
     rp = ('<rp>（</rp>', '<rp>）</rp>')
 
     return f'<ruby>{rb}{rp[0]}{rt}{rp[1]}</ruby>'
@@ -341,7 +345,7 @@ class KanaText(nodes.Node):
 
     children = () #これでTextクラスと同じ扱いになる.
 
-    def __init__(self, rawword, separator=_dflt_separator, option_marker=_dflt_option_marker):
+    def __init__(self, rawword, config=None):
         """
         doctest:
 
@@ -350,12 +354,22 @@ class KanaText(nodes.Node):
             <KanaText: len=2 ruby='specific' option='b1' <#text: 'はなこ|はな子'>>
         """
 
+        if config and _dflt_separator != config.kana_text_separator:
+            separator = config.kana_text_separator
+        else:
+            separator = _dflt_separator
+
+        if config and _dflt_option_marker != config.kana_text_option_marker:
+            option_marker = config.kana_text_option_marker
+        else:
+            option_marker = _dflt_option_marker
+
         self._rawword = rawword
         self._delimiter = _chop.sub('', separator)
         self._separator = separator
         self._option_marker = option_marker
 
-        self.whatiam = 'term' #in('classifier', 'term', 'subterm')
+        self.whatiam = 'term' #in('classifier', 'term')
 
         parser = parser_for_kana_text(separator, option_marker)
         hier, kana, ruby, option = self._parse_text(rawword.strip(), parser)
@@ -381,9 +395,7 @@ class KanaText(nodes.Node):
     def __setitem__(self, key, value):
         """必要なものに限定する."""
         if isinstance(key, str):
-            if key == 'whatiam':
-                self.whatiam = value
-            elif key in ('ruby', 'option'):
+            if key in ('ruby', 'option'):
                 self._properties[key] = value
             else:
                 raise KeyError(key)
@@ -401,20 +413,10 @@ class KanaText(nodes.Node):
 
     def __str__(self):
         """jinja2用"""
-        return self.ashier()
-
-    def __iter__(self):
-        """jinja2用"""
-        self._iterator = self.asruby()
-        self._iter_counter = -1
-        return self
-
-    def __next__(self):
-        self._iter_counter += 1
-        try:
-            return self._iterator[self._iter_counter]
-        except IndexError:
-            raise StopIteration
+        if self.whatiam == 'term' and self.html_kana_text_on_genindex:
+            return self.ashtml()
+        else:
+            return self.ashier()
 
     def __repr__(self):
         return self.entity_of_repr()
@@ -441,7 +443,7 @@ class KanaText(nodes.Node):
         elif self._rawword:
             return f"<{name}: <#rawword: '{self._rawword}'>>"
         else:
-            return f"<{name}: <#empty>>"
+            return f"<#empty>"
 
     def _parse_text(self, text, parser):
         """
@@ -562,34 +564,28 @@ class KanaText(nodes.Node):
 
 _each_words = re.compile(r' *; +')
 
-class KanaTextUnit(nodes.Element):
+class ExIndexEntry(idxr.IndexEntry):
 
     _number_of_terms = { 'single': 2, 'pair': 2, 'triple': 3, 'see': 2, 'seealso': 2, 'list': 99}
 
-    def __init__(self, rawtext, entry_type='single', file_name=None, target=None, main='', index_key=''):
+    def __init__(self, rawtext, entry_type='single', file_name=None, target=None, main='',
+                 index_key='', textclass=None):
 
-        rawwords = _each_words.split(rawtext)
-
-        terms = []
-        for rawword in rawwords:
-            terms.append(KanaText(rawword))
-
-        super().__init__(rawtext, *terms, entry_type=entry_type, 
-                         file_name=file_name, target=target, main=main, index_key=index_key)
+        super().__init__(rawtext, entry_type, file_name, target, main, index_key, KanaText)
 
     def __repr__(self):
         """
         doctest:
 
-            >>> ktext = KanaTextUnit('壱壱; 弐弐')
+            >>> ktext = ExIndexEntry('壱壱; 弐弐')
             >>> ktext
-            <KanaTextUnit: entry_type='single' <KanaText: len=1 <#text: '壱壱'>><KanaText: len=1 <#text: '弐弐'>>>
-            >>> ktext = KanaTextUnit('ああ|壱壱^')
+            <ExIndexEntry: entry_type='single' <KanaText: len=1 <#text: '壱壱'>><KanaText: len=1 <#text: '弐弐'>>>
+            >>> ktext = ExIndexEntry('ああ|壱壱^')
             >>> ktext
-            <KanaTextUnit: entry_type='single' <KanaText: len=2 ruby='on' <#text: 'ああ|壱壱'>>>
-            >>> ktext = KanaTextUnit('あ|壱^1')
+            <ExIndexEntry: entry_type='single' <KanaText: len=2 ruby='on' <#text: 'ああ|壱壱'>>>
+            >>> ktext = ExIndexEntry('あ|壱^1')
             >>> ktext
-            <KanaTextUnit: entry_type='single' <KanaText: len=2 ruby='specific' option='1' <#text: 'あ|壱'>>>
+            <ExIndexEntry: entry_type='single' <KanaText: len=2 ruby='specific' option='1' <#text: 'あ|壱'>>>
         """
 
         name = self.__class__.__name__
@@ -608,74 +604,16 @@ class KanaTextUnit(nodes.Element):
 
         return prop
 
-    def make_index_units(self):
-        index_units = []
-
-        entry_type = self['entry_type']
-        fn = self['file_name']
-        tid = self['target']
-        main = self['main']
-        index_key = self['index_key']
-
-        def _index_unit(ent, sub1, sub2):
-            if entry_type in ('see', 'seealso'):
-                emphasis = _emphasis2char[entry_type]
-            else:
-                emphasis = _emphasis2char[main]
-
-            try:
-                text1 = sub1._rawword
-            except AttributeError:
-                text1 = ''
-            try:
-                text2 = sub2._rawword
-            except AttributeError:
-                text2 = ''
-
-            index_unit = IndexUnit(ent._rawword, text1, text2, emphasis, fn, tid, index_key, KanaText)
-            return index_unit
-
-        try:
-            #_index_unit(term, subterm1, subterm2)
-            if entry_type == 'single':
-                try:
-                    index_units.append(_index_unit(self[0], self[1], ''))
-                except IndexError:
-                    index_units.append(_index_unit(self[0], '', ''))
-            elif entry_type == 'pair':
-                index_units.append(_index_unit(self[0], self[1], ''))
-                index_units.append(_index_unit(self[1], self[0], ''))
-            elif entry_type == 'triple':
-                index_units.append(_index_unit(self[0], self[1], self[2]))
-                u = _index_unit(self[1], self[2], self[0])
-                u.set_subterm_delimiter(', ')
-                index_units.append(u)
-                index_units.append(_index_unit(self[2], self[0], self[1]))
-            elif entry_type == 'see':
-                index_units.append(_index_unit(self[0], self[1], ''))
-            elif entry_type == 'seealso':
-                index_units.append(_index_unit(self[0], self[1], ''))
-            elif entry_type in self._number_of_terms:
-                for i in range(len(self)):
-                    index_units.append(_index_unit(self[i], '', ''))
-            else:
-                logger.warning(__('unknown index entry type %r'), entry_type,
-                                  location=fn)
-        except ValueError as err:
-            logger.warning(str(err), location=fn)
-
-        return index_units
-
     def askana(self, concat=(', ', 3)):
         """
         doctest:
-            >>> ktext = KanaTextUnit('壱壱')
+            >>> ktext = ExIndexEntry('壱壱')
             >>> ktext.askana()
             ''
-            >>> ktext = KanaTextUnit('ああ|壱壱^11')
+            >>> ktext = ExIndexEntry('ああ|壱壱^11')
             >>> ktext.askana()
             'ああ'
-            >>> ktext = KanaTextUnit('ああ|壱壱^11; いい|弐弐; うう|参参^11')
+            >>> ktext = ExIndexEntry('ああ|壱壱^11; いい|弐弐; うう|参参^11')
             >>> ktext.askana()
             'ああ, いい, うう'
         """
@@ -685,13 +623,13 @@ class KanaTextUnit(nodes.Element):
     def ashier(self, concat=(', ', 3)):
         """
         doctest:
-            >>> ktext = KanaTextUnit('壱壱')
+            >>> ktext = ExIndexEntry('壱壱')
             >>> ktext.ashier()
             '壱壱'
-            >>> ktext = KanaTextUnit('ああ|壱壱^11')
+            >>> ktext = ExIndexEntry('ああ|壱壱^11')
             >>> ktext.ashier()
             '壱壱'
-            >>> ktext = KanaTextUnit('ああ|壱壱^11; いい|弐弐; うう|参参^11')
+            >>> ktext = ExIndexEntry('ああ|壱壱^11; いい|弐弐; うう|参参^11')
             >>> ktext.ashier()
             '壱壱, 弐弐, 参参'
         """
@@ -701,13 +639,13 @@ class KanaTextUnit(nodes.Element):
     def astext(self, concat=('; ', 3)):
         """
         doctest:
-            >>> ktext = KanaTextUnit('壱壱')
+            >>> ktext = ExIndexEntry('壱壱')
             >>> ktext.astext()
             '壱壱'
-            >>> ktext = KanaTextUnit('ああ|壱壱^11')
+            >>> ktext = ExIndexEntry('ああ|壱壱^11')
             >>> ktext.astext()
             'ああ|壱壱'
-            >>> ktext = KanaTextUnit('ああ|壱壱^11; いい|弐弐; うう|参参^11')
+            >>> ktext = ExIndexEntry('ああ|壱壱^11; いい|弐弐; うう|参参^11')
             >>> ktext.astext()
             'ああ|壱壱; いい|弐弐; うう|参参'
         """
@@ -717,7 +655,7 @@ class KanaTextUnit(nodes.Element):
     def asruby(self):
         """
         doctest:
-            >>> kanatext = KanaTextUnit('ああ|壱壱; いい|弐弐^; うう|参参')
+            >>> kanatext = ExIndexEntry('ああ|壱壱; いい|弐弐^; うう|参参')
             >>> kanatext.asruby()
             [[(False, '壱壱')], [(True, ('弐弐', 'いい'))], [(False, '参参')]]
         """
@@ -848,43 +786,6 @@ _first_char_large = {
     'ラ': 'ら', 'リ': 'り', 'ル': 'る', 'レ': 'れ', 'ロ': 'ろ', 
     'わ': 'わ', 'を': 'を', 'ん': 'ん', 'ワ': 'わ', 'ヲ': 'を', 'ン': 'ん' }
 
-#1-5: IndexRack.put_in_kana_catalogでの優先順.
-#3,5: 同一subterm内でのリンクの表示順.
-#8,9: 同一term内でのsubtermの表示順.
-_emphasis2char = {
-    '_cnfpy_': '1', #「conf.py/kana_text_word_list」
-    '_rncmd_': '2', #「~/.sphinx/kana_catalog.py」
-    'main':    '3', #glossaryで定義した用語. indexでは「!」が先頭にあるもの.
-    '_rsvd4_': '4', #reserved
-    '':        '5', #'main', 'see', 'seealso'以外.
-    '_rsvd6_': '6', #reserved
-    '_rsvd7_': '7', #reserved
-    'see':     '8',
-    'seealso': '9',
-}
-
-_char2emphasis = {
-    '0': '', '1': '', '2': '', '3': 'main', '4': '',
-    '5': '', '6': '', '7': '', '8': 'see', '9': 'seealso',
-}
-
-def make_classifier_from_first_letter(text, config):
-    """
-    先頭の一文字を必要な加工をして分類子に使う.
-    """
-    try:
-        #パラメータに応じて変換テーブルを使い分ける.
-        if 'small' == config.kana_text_indexer_mode:
-            return _first_char_small[text[:1]]
-        elif 'large' == config.kana_text_indexer_mode:
-            return _first_char_large[text[:1]]
-        else:
-            #想定パラメータ以外なら基本的な処理
-            return text[:1].upper()
-    except KeyError:
-        #変換表になければ基本的な処理
-        return text[:1].upper()
-
 def get_word_list_from_file(config):
     if not config.kana_text_word_file: return []
 
@@ -896,12 +797,12 @@ def get_word_list_from_file(config):
 
     return lines
 
-class IndexRack(object):
+class ExIndexRack(idxr.IndexRack):
     """
     処理概要
 
     1. self.__init__() 初期化. 設定からの読み込み.
-    2. self.append() IndexUnitの取り込み. self.update()の準備.
+    2. self.append() ExIndexUnitの取り込み. self.update()の準備.
     3. self.update_units() 各unitの更新、並び替えの準備.
     4. self.sort_units() 並び替え.
     5. self.generate_genindex_data() genindex用データの生成.
@@ -910,90 +811,59 @@ class IndexRack(object):
     UNIT_CLSF, UNIT_TERM, UNIT_SBTM, UNIT_EMPH = 0, 1, 2, 3
 
     def __init__(self, builder, testmode=False):
-        """IndexUnitの取り込み、整理、並べ替え. データの生成."""
+        """ExIndexUnitの取り込み、整理、並べ替え. データの生成."""
 
         #制御情報の保存
-        self.env = builder.env
-        self.config = builder.config
-        self.get_relative_uri = builder.get_relative_uri
         self.testmode = testmode #0.24 未使用になった.
-
         self._kana_catalog = {} # {term: (emphasis, kana)} #KanaText
 
         #設定で用意されたかな文字情報の登録
-        for rawword in self.config.kana_text_word_list:
-            unit = KanaTextUnit(rawword, 'list', 'WORD_LIST', '', '_cnfpy_', None) #_cnfpy_
-            index_units = unit.make_index_units()
+        for rawword in builder.config.kana_text_word_list:
+            entry = ExIndexEntry(rawword, 'list', 'WORD_LIST', '', 'conf.py', None) #_cnfpy_
+            entry.unitclass = ExIndexUnit
+            entry.packclass = ExSubTerm
+            index_units = entry.make_index_units()
             for iu in index_units:
                 self.put_in_kana_catalog(iu[self.UNIT_EMPH], iu.get_children())
 
         #設定ファイルで用意されたかな文字情報の登録
-        for rawword in get_word_list_from_file(self.config):
-            unit = KanaTextUnit(rawword, 'list', 'WORD_FILE', '', '_rncmd_', None) #_rncmd_
-            index_units = unit.make_index_units()
+        for rawword in get_word_list_from_file(builder.config):
+            entry = ExIndexEntry(rawword, 'list', 'WORD_FILE', '', 'valuerc', None) #_rncmd_
+            entry.unitclass = ExIndexUnit
+            entry.packclass = ExSubTerm
+            index_units = entry.make_index_units()
             for iu in index_units:
                 self.put_in_kana_catalog(iu[self.UNIT_EMPH], iu.get_children())
 
+        super().__init__(builder)
+
     def create_genindex(self, entries=None, group_entries: bool = True,
                      _fixre: Pattern = re.compile(r'(.*) ([(][^()]*[)])')
                      ) -> List[Tuple[str, List[Tuple[str, Any]]]]:
         """IndexEntriesクラス/create_indexメソッドを置き換える."""
 
-        #引数の保存
-        self._group_entries = group_entries
-        self._fixre = _fixre
-
         #入れ物の用意とリセット
         self._kana_catalog_pre = self._kana_catalog #(注)__init__がないと前回分が残る.
-        self._rack = [] # [IndexUnit, IndexUnit, ...]
-        self._classifier_catalog = {} # {term: classifier} 
         self._kana_catalog = {} # {term: (emphasis, kana, ruby, option)}
-        self._function_catalog = {} #{function name: number of homonymous funcion}
 
-        #get entries（引数にあるentriesは単体テストからの受け取り場所）
-        if not entries:
-            domain = cast(IndexDomain, self.env.get_domain('index'))
-            entries = domain.entries
-        #entries: Dict{ファイル名: List[Tuple(type, value, tid, main, index_key)]}
+        #クラスの設定
+        self.textclass = KanaText
+        self.entryclass = ExIndexEntry
+        self.unitclass = ExIndexUnit
+        self.packclass = ExSubTerm
 
-        for fn, entries in entries.items():
-            for entry_type, value, tid, main, index_key in entries:
-                unit = KanaTextUnit(value, entry_type, fn, tid, main, index_key)
-                index_units = unit.make_index_units()
-                self.extend(index_units)
-
-        self.update_units()
-        self.sort_units()
-
-        return self.generate_genindex_data() 
+        return super().create_genindex(group_entries, _fixre)
 
     def append(self, unit):
         """
         - 全unitを見て決める更新処理のための情報収集
         """
         #情報収集
-        self.put_in_classifier_catalog(unit['index_key'], unit[self.UNIT_TERM].ashier())
-        self.put_in_kana_catalog(unit[self.UNIT_EMPH], unit.get_children()) #KanaText
+        self.put_in_kana_catalog(unit[self.UNIT_EMPH], unit.get_children()) 
+        unit[self.UNIT_TERM].html_kana_text_on_genindex = self.config.html_kana_text_on_genindex
 
-        #情報収集
-        if self._group_entries:
-            self.put_in_function_catalog(unit.astexts(), self._fixre)
-
-        #unitをrackに乗せる
-        self._rack.append(unit)
-
-    def extend(self, units):
-        for unit in units:
-            self.append(unit)
-
-    def put_in_classifier_catalog(self, index_key, hier):
-        """Text/KanaText共通の処理"""
-        if not index_key: return
-        if not hier: return
-
-        if not hier in self._classifier_catalog:
-            #上書きはしない.（∵「make clean」での状況を真とするため）
-            self._classifier_catalog[hier] = index_key
+        #残りの処理
+        super().append(unit)
 
     def put_in_kana_catalog(self, emphasis, terms): #KanaText
         """KanaText用の処理"""
@@ -1010,7 +880,7 @@ class IndexRack(object):
                         self._kana_catalog[hier] = (emphasis, kana, ruby, spec)
                     #検討）かな文字の長さも同じなら、、
                     elif len(kana) == len(item[1]):
-                        #specificに限りオプションコードが多い方を採用する.
+                        #'specific'に限りオプションコードが多い方を採用する.
                         if ruby == 'specific' and ruby == item[2] and len(spec) > len(item[3]):
                             self._kana_catalog[hier] = (emphasis, kana, ruby, spec)
                     else:
@@ -1021,16 +891,22 @@ class IndexRack(object):
             elif kana:
                 self._kana_catalog[hier] = (emphasis, kana, ruby, spec)
 
-    def put_in_function_catalog(self, texts, _fixre):
-        for text in texts:
-            m = _fixre.match(text)
-            if m:
-                try:
-                    self._function_catalog[m.group(1)] += 1
-                except KeyError:
-                    self._function_catalog[m.group(1)] = 1
+    def make_classifier_from_first_letter(self, text):
+        """
+        先頭の一文字を必要な加工をして分類子に使う.
+        """
+        try:
+            #パラメータに応じて変換テーブルを使い分ける.
+            if 'small' == self.config.kana_text_indexer_mode:
+                return _first_char_small[text[:1]]
+            elif 'large' == self.config.kana_text_indexer_mode:
+                return _first_char_large[text[:1]]
             else:
-                pass
+                #想定パラメータ以外なら基本的な処理
+                return text[:1].upper()
+        except KeyError:
+            #変換表になければ基本的な処理
+            return text[:1].upper()
 
     def update_units(self):
         """rackに格納されている全てのunitの更新を行う."""
@@ -1042,11 +918,6 @@ class IndexRack(object):
         for unit in self._rack:
             assert [unit[self.UNIT_TERM]]
 
-            #複数ある同名関数の更新
-
-            if self._group_entries:
-                self.update_unit_with_function_catalog(unit)
-
             #各termの読みの設定（「同じ単語は同じ読み」とする）
 
             self.update_term_with_kana_catalog(unit[self.UNIT_TERM])
@@ -1054,60 +925,11 @@ class IndexRack(object):
             for subterm in unit[self.UNIT_SBTM]._terms:
                 self.update_term_with_kana_catalog(subterm)
 
-            #classifierの設定（［重要］if/elifの判定順）
-            #- self._kana_catalogの内容は反映しない.
-            #- 同じ用語が複数glossaryである場合、分類子は一箇所で設定すべき
-            #- 複数の同じ用語が別々の分類子を設定していた場合、集約されるのは一つのみ.
-            #- 複数箇所で設定していた場合は、修正すべき用語が特定できるようにする.
-
-            ikey = unit['index_key']
-            term = unit[self.UNIT_TERM]
-
-            #［重要］if/elifの判定順
-            if ikey:
-                unit[self.UNIT_CLSF] = unit.textclass(ikey)
-            elif term.ashier() in self._classifier_catalog:
-                unit[self.UNIT_CLSF] = unit.textclass(self._classifier_catalog[term.ashier()])
-            else:
-                text = unit[self.UNIT_TERM].astext()
-                char = make_classifier_from_first_letter(text, self.config)
-                unit[self.UNIT_CLSF] = unit.textclass(char)
-
-            #sortkeyの設定
-            #'see', 'seealso'の表示順に手を加える.
-
-            if unit[self.UNIT_EMPH] in ('7', '8', '9'):
-                order_code = '2' #'see' or 'seealso'
-            else:
-                order_code = '1' #'main' or ''
-
-            unit._sort_order = order_code
-
-    def update_unit_with_function_catalog(self, unit):
-        """
-        fixup entries: transform
-          func() (in module foo)
-          func() (in module bar)
-        into
-          func()
-            (in module foo)
-            (in module bar) 
-        """
-        i_tm = unit[self.UNIT_TERM]
-        m = self._fixre.match(i_tm.astext()) #astext()とashier()に差異はない.
-
-        #_fixreが想定する形で関数名とモジュール名があり、同じ名前の関数が複数ある場合.
-        if m and self._function_catalog[m.group(1)] > 1:
-            #状況的にsubtermは空のはず.
-            assert not unit[self.UNIT_SBTM], f'{self.__class__.__name__}: subterm is not null'
-
-            unit[self.UNIT_TERM] = unit.textclass(m.group(1))
-            obj = unit.textclass(m.group(2))
-            obj['whatiam'] = 'subterm'
-            unit[self.UNIT_SBTM] = SubTerm()
-            unit[self.UNIT_SBTM].append(obj)
-        #subの情報が消えるが、このケースに該当する場合はsubにはデータがないはず.
+        super().update_units()
 
+    def get_word(self, term):
+        return term.ashier()
+    
     def update_term_with_kana_catalog(self, term):
         if term.ashier() in self._kana_catalog:
             term[1] = self._kana_catalog[term.ashier()][1]
@@ -1116,121 +938,17 @@ class IndexRack(object):
         else:
             pass
 
-    def sort_units(self):
-        self._rack.sort(key=lambda x: (
-            x[self.UNIT_CLSF].astext(), #classifier
-            x[self.UNIT_TERM].astext(), #term
-            x._sort_order,              #entry type in('see', 'seealso')
-            x[self.UNIT_SBTM].astext(), #subterm
-            x[self.UNIT_EMPH],          #emphasis(main)
-            x['file_name'], x['target']))
-        #x['file_name'], x['target']は、0.21の動作仕様に合わせるため.
-        #逆にすると内部的な処理順に依存するため、現状の動作仕様を維持する.
-
-    def generate_genindex_data(self):
-        """
-        Text/KanaTextの選択を意識して書く.
-        （Text側で__eq__が実装されることが前提）
-        """
-        rtnlist = [] #判定用
-
-        _clf, _tm, _sub = -1, -1, -1
-        for unit in self._rack: #rackからunitを取り出す
-            i_clf = unit[self.UNIT_CLSF]
-            i_tm  = unit[self.UNIT_TERM]
-            i_sub = unit[self.UNIT_SBTM] #see: SubTerm
-            i_em  = unit[self.UNIT_EMPH]
-            i_fn  = unit['file_name']
-            i_tid = unit['target']
-            i_iky = unit['index_key']
-
-            #make a uri
-            if i_fn:
-                try:
-                    r_uri = self.get_relative_uri('genindex', i_fn) + '#' + i_tid
-                except NoUri:
-                    continue
-
-            #see: KanaText.__ne__
-            if len(rtnlist) == 0 or not rtnlist[_clf][0] == i_clf.astext(): #use __eq__
-                i_clf['whatiam'] = 'classifier'
-                rtnlist.append((i_clf, []))
-
-                #追加された「(clf, [])」を見るように_clfを更新する. 他はリセット.
-                _clf, _tm, _sub = _clf+1, -1, -1
-
-            r_clsfr = rtnlist[_clf] #[classifier, [term, term, ..]]
-            r_clfnm = r_clsfr[0] #classifier is KanaText object.
-            r_subterms = r_clsfr[1] #[term, term, ..]
-
-            #see: KanaText.__ne__
-            if len(r_subterms) == 0 or not r_subterms[_tm][0] == i_tm.astext(): #use __eq__
-                r_subterms.append((i_tm, [[], [], i_iky]))
-                _tm, _sub = _tm+1, -1
-
-            r_term = r_subterms[_tm]       #[term, [links, [subterm, subterm, ..], index_key]
-            r_term_value = r_term[0]    #term_value is KanaText object.
-            r_term_links = r_term[1][0] #[(main, uri), (main, uri), ..]
-            r_subterms = r_term[1][1]   #[subterm, subterm, ..]
-
-            #一文字から元の文字列に戻す
-            r_main = _char2emphasis[i_em]
-
-            #see/seealsoならリンク情報を消す
-            if r_main in ('see', 'seealso'):
-                r_fn = None
-            else:
-                r_fn = i_fn
-                
-            #sub(class SubTerm): [], [KanaText], [KanaText, KanaText].
-            if len(i_sub) == 0:
-                if r_fn: r_term_links.append((r_main, r_uri))
-            elif len(r_subterms) == 0 or not r_subterms[_sub][0] == i_sub.astext():
-                if self.config.html_change_triple:
-                    i_sub.change_triple = True
-                r_subterms.append((i_sub, []))
-
-                _sub = _sub+1
-                r_subterm = r_subterms[_sub]
-                r_subterm_value = r_subterm[0]
-                r_subterm_links = r_subterm[1]
-                if r_fn: r_subterm_links.append((r_main, r_uri))
-            else:
-                if r_fn: r_subterm_links.append((r_main, r_uri))
-
-        return rtnlist
-
-class SubTerm(nodes.reprunicode):
+class ExSubTerm(idxr.SubTerm):
     """
     Jinja2に「文字列」と思わせるには「node.repruniocde」の継承が必要.
     （実体はstrだけど、Sphinxの流儀に従っていた方が無難）
     """
-    def __init__(self, template=None):
-        self._terms = []
-        self._delimiter = ' '
-        self._template = template
+    def __init__(self, emphasis, *terms):
         self.change_triple = False
-    def set_delimiter(self, delimiter=', '):
-        #デフォルトから変更する場合は「', '」のパターンしかない.
-        self._delimiter = delimiter
-    def __repr__(self):
-        rpr  = f"<{self.__class__.__name__}: len={len(self)} "
-        if self._template: rpr += f"tpl='{self._template}' "
-        for s in self._terms:
-            rpr += repr(s)
-        rpr += ">"
-        return rpr
+        super().__init__(emphasis, *terms)
     def __str__(self):
         """Jinja2用"""
-        return self.ashier()
-    def __eq__(self, other):
-        """unittest、IndexRack.generate_genindex_data用."""
-        return self.astext() == other
-    def __len__(self):
-        return len(self._terms)
-    def append(self, subterm):
-        subterm['whatiam'] = 'subterm'
-        self._terms.append(subterm)
+        return nodes.unescape(self.ashier())
     def astext(self):
         if self._template and len(self) == 1:
             return self._template % self._terms[0].ashier()
@@ -1251,102 +969,12 @@ class SubTerm(nodes.reprunicode):
             hier += subterm.ashier() + self._delimiter
         return hier[:-len(self._delimiter)]
 
-class IndexUnit(object):
+class ExIndexUnit(idxr.IndexUnit):
 
     CLSF, TERM, SBTM, EMPH = 0, 1, 2, 3
 
-    def __init__(self, term, subterm1, subterm2, emphasis, file_name, target, index_key, textclass=nodes.Text):
-        """
-        - リンクを作成しない場合は、file_name, targetは空文字かNoneにする.
-        - Text/KanaTextを選択できる口だけ用意しているけど、実装はKanaText用でやっている.
-        - IndexUnitを継承してKanaIndexUnitを定義するようなIndexUnitにすればイケる.
-        """
-
-        if emphasis == '8':
-            subterm = SubTerm(_('see %s'))
-        elif emphasis == '9':
-            subterm = SubTerm(_('see also %s'))
-        else:
-            subterm = SubTerm()
-
-        for sbtm in (subterm1, subterm2):
-            if sbtm:
-                obj = textclass(sbtm)
-                obj['whatiam'] = 'subterm'
-                subterm.append(obj)
-
-        self._sort_order = None
-        self._display_data = [textclass(''), textclass(term), subterm] #classifierを更新するのでタプルにはできない.
-        self._link_data = (emphasis, file_name, target)
-        self._index_key = index_key
-
-        self.textclass = textclass
-
-    def __repr__(self):
-        """
-        >>> iu = IndexUnit('', '', '', '5', 'doc1', 'id-1', '分類子', KanaText)
-        >>> iu
-        <IndexUnit: main='5' file_name='doc1' target='id-1' <KanaText: <#empty>><KanaText: <#empty>>>
-        >>> iu = IndexUnit('壱', '弐', '', '8', '', '', None, KanaText)
-        >>> iu
-        <IndexUnit: main='8' <KanaText: <#empty>><KanaText: len=1 <#text: '壱'>><SubTerm: len=1 tpl='see %s' <KanaText: len=1 <#text: '弐'>>>>
-        """
-        name = self.__class__.__name__
-        main = self['main']
-        fn = self['file_name']
-        tid = self['target']
-        rpr  = f"<{name}: "
-        if main: rpr += f"main='{main}' "
-        if fn: rpr += f"file_name='{fn}' "
-        if tid: rpr += f"target='{tid}' "
-        rpr += repr(self[0]) + repr(self[1])
-        if len(self[2]) > 0: rpr += repr(self[2])
-        rpr += ">"
-        return rpr
-
-    def __getitem__(self, key):
-        if isinstance(key, str):
-            if key == 'main':      return self._link_data[0]
-            if key == 'file_name': return self._link_data[1]
-            if key == 'target':    return self._link_data[2]
-            if key == 'index_key': return self._index_key
-            raise KeyError(key)
-        elif isinstance(key, int):
-            if key == self.CLSF: return self._display_data[self.CLSF] #classifier
-            if key == self.TERM: return self._display_data[self.TERM] #term
-            if key == self.SBTM: return self._display_data[self.SBTM] #subterm
-            if key == self.EMPH: return self._link_data[0]    #emphasis(main)
-            raise KeyError(key)
-        else:
-            raise TypeError(key)
-
-    def __setitem__(self, key, value): #更新するデータだけ対応する.
-        if isinstance(key, int):
-            if key == self.CLSF: self._display_data[self.CLSF] = value
-            elif key == self.TERM: self._display_data[self.TERM] = value
-            elif key == self.SBTM: self._display_data[self.SBTM] = value
-            elif key == self.EMPH: self._display_data[self.EMPH] = value
-            else: raise KeyError(key)
-        else:
-            raise KeyError(key)
-
-    def get_children(self):
-        children = [self[self.TERM]]
-        if self[2]:
-            for child in self[self.SBTM]._terms:
-                children.append(child)
-        return children
-
-    def set_subterm_delimiter(self, delimiter=', '):
-        self[self.SBTM].set_delimiter(delimiter)
-
-    def astexts(self):
-        texts = [self[self.TERM].astext()]
-
-        for subterm in self[self.SBTM]._terms:
-            texts.append(subterm.astext())
-
-        return texts
+    def __init__(self, term, subterm, emphasis, file_name, target, index_key):
+        super().__init__(term, subterm, emphasis, file_name, target, index_key)
 
     def askanas(self):
         kanas = [self[self.TERM].askana()]
@@ -1367,56 +995,15 @@ class IndexUnit(object):
 
 #------------------------------------------------------------
 
-class _StandaloneHTMLBuilder(builders.StandaloneHTMLBuilder):
-    """
-    オリジナルに依存する部分と拡張部分を区別するために用意したクラス.
-    """
-
-    def create_genindex(self) -> None: #KaKkou
-        """
-        このように分けてくれると、self.create_index()を書き換えるだけで済む.
-        """
-
-        return IndexEntries(self.env).create_index(self)
-
-    def write_genindex(self) -> None:
-        genindex = self.create_genindex()
-
-        #以降の処理はSphinx4.1.2オリジナルと同じ
-        indexcounts = []
-        for _k, entries in genindex:
-            indexcounts.append(sum(1 + len(subitems)
-                                   for _, (_, subitems, _) in entries))
-
-        genindexcontext = {
-            'genindexentries': genindex,
-            'genindexcounts': indexcounts,
-            'split_index': self.config.html_split_index,
-        }
-        logger.info('genindex ', nonl=True)
-
-        if self.config.html_split_index:
-            self.handle_page('genindex', genindexcontext,
-                             'genindex-split.html')
-            self.handle_page('genindex-all', genindexcontext,
-                             'genindex.html')
-            for (key, entries), count in zip(genindex, indexcounts):
-                ctx = {'key': key, 'entries': entries, 'count': count,
-                       'genindexentries': genindex}
-                self.handle_page('genindex-' + key, ctx,
-                                 'genindex-single.html')
-        else:
-            self.handle_page('genindex', genindexcontext, 'genindex.html')
-
-class KanaHTMLBuilder(_StandaloneHTMLBuilder):
+class KanaHTMLBuilder(idxr.HTMLBuilder):
     """索引ページの日本語対応"""
 
     name = 'kana'
 
-    def create_genindex(self) -> None: #KaKkou
+    def index_adapter(self) -> None: #KaKkou
         """索引の作成"""
         #自前のIndexerを使う
-        return IndexRack(self).create_genindex()
+        return ExIndexRack(self).create_genindex()
 
 #------------------------------------------------------------
 
@@ -1472,7 +1059,7 @@ def setup(app) -> Dict[str, Any]:
 
     #glossaryディレクティブ、kanaロールの表示用
     app.add_node(KanaText, html=(visit_kana, depart_kana))
-    app.add_node(KanaTextUnit, html=(visit_kana, depart_kana))
+    app.add_node(ExIndexEntry, html=(visit_kana, depart_kana))
     #索引の表示はKanaHTMLBuilderで行う
 
     #HTML出力
@@ -1480,8 +1067,8 @@ def setup(app) -> Dict[str, Any]:
     app.set_translator('kana', KanaHTML5Translator)
 
     #設定の登録
-    app.add_config_value('kana_text_separator', r'\|', 'env') 
-    app.add_config_value('kana_text_option_marker', r'\^', 'env') 
+    app.add_config_value('kana_text_separator', _dflt_separator, 'env') 
+    app.add_config_value('kana_text_option_marker', _dflt_option_marker, 'env') 
     app.add_config_value('kana_text_word_file', '', 'env') 
     app.add_config_value('kana_text_word_list', (), 'env') 
     app.add_config_value('kana_text_indexer_mode', 'small', 'env') 
